Struct Buttons

pub struct Buttons { /* private fields */ }
Store the state of the Buttons.

The Buttons do not connect to GPIO pins directly. Instead they connect to an 8-channel shift register to save pins. This result thate they must be manual updated by calling .update() and can not be acess directly.

Implementations

Source

impl Buttons

pub fn some_pressed(&self) -> bool

Check if some key is pressed.

pub fn none_pressed(&self) -> bool

Check if none key is pressed

pub fn button_pressed(&self, button: Button) -> bool

Check if a button is pressed

pub fn a_pressed(&self) -> bool

pub fn b_pressed(&self) -> bool

pub fn start_pressed(&self) -> bool

pub fn select_pressed(&self) -> bool

pub fn right_pressed(&self) -> bool

pub fn down_pressed(&self) -> bool

pub fn up_pressed(&self) -> bool

pub fn left_pressed(&self) -> bool

pub fn events(&self) -> EventIter<'_>

Iterator over alle Events (Button status changes) occured between the last and penultimate update.

This does only include the changes of Buttons! For example if a button was pressed at the penultimate update und is still pressed at the last update, the iterator does skip the button.

pub fn update(&mut self)

Update the state of the buttons. 400ns total blocking read.