pub struct Buttons { /* private fields */ }Expand description
Implementations
Sourceimpl Buttons
impl Buttons
Sourcepub fn some_pressed(&self) -> bool
pub fn some_pressed(&self) -> bool
Check if some key is pressed.
Sourcepub fn none_pressed(&self) -> bool
pub fn none_pressed(&self) -> bool
Check if none key is pressed
Check if a button is pressed
pub fn a_pressed(&self) -> bool
pub fn b_pressed(&self) -> bool
pub fn start_pressed(&self) -> bool
pub fn select_pressed(&self) -> bool
pub fn right_pressed(&self) -> bool
pub fn down_pressed(&self) -> bool
pub fn up_pressed(&self) -> bool
pub fn left_pressed(&self) -> bool
Sourcepub fn events(&self) -> EventIter<'_> ⓘ
pub fn events(&self) -> EventIter<'_> ⓘ
Iterator over alle Events (Button status changes) occured between the last and penultimate update.
This does only include the changes of Buttons! For example if a button was pressed at the penultimate update und is still pressed at the last update, the iterator does skip the button.